# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Cognito User Pools'
prefix = 'cognito-idp'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddCustomAttributes = Action('AddCustomAttributes')
AdminAddUserToGroup = Action('AdminAddUserToGroup')
AdminConfirmSignUp = Action('AdminConfirmSignUp')
AdminCreateUser = Action('AdminCreateUser')
AdminDeleteUser = Action('AdminDeleteUser')
AdminDeleteUserAttributes = Action('AdminDeleteUserAttributes')
AdminDisableUser = Action('AdminDisableUser')
AdminEnableUser = Action('AdminEnableUser')
AdminForgetDevice = Action('AdminForgetDevice')
AdminGetDevice = Action('AdminGetDevice')
AdminGetUser = Action('AdminGetUser')
AdminInitiateAuth = Action('AdminInitiateAuth')
AdminListDevices = Action('AdminListDevices')
AdminListGroupsForUser = Action('AdminListGroupsForUser')
AdminRemoveUserFromGroup = Action('AdminRemoveUserFromGroup')
AdminResetUserPassword = Action('AdminResetUserPassword')
AdminRespondToAuthChallenge = Action('AdminRespondToAuthChallenge')
AdminSetUserSettings = Action('AdminSetUserSettings')
AdminUpdateDeviceStatus = Action('AdminUpdateDeviceStatus')
AdminUpdateUserAttributes = Action('AdminUpdateUserAttributes')
AdminUserGlobalSignOut = Action('AdminUserGlobalSignOut')
CreateGroup = Action('CreateGroup')
CreateUserImportJob = Action('CreateUserImportJob')
CreateUserPool = Action('CreateUserPool')
CreateUserPoolClient = Action('CreateUserPoolClient')
DeleteGroup = Action('DeleteGroup')
DeleteUserPool = Action('DeleteUserPool')
DeleteUserPoolClient = Action('DeleteUserPoolClient')
DescribeUserImportJob = Action('DescribeUserImportJob')
DescribeUserPool = Action('DescribeUserPool')
DescribeUserPoolClient = Action('DescribeUserPoolClient')
GetCSVHeader = Action('GetCSVHeader')
GetGroup = Action('GetGroup')
ListGroups = Action('ListGroups')
ListUserImportJobs = Action('ListUserImportJobs')
ListUserPoolClients = Action('ListUserPoolClients')
ListUserPools = Action('ListUserPools')
ListUsers = Action('ListUsers')
ListUsersInGroup = Action('ListUsersInGroup')
StartUserImportJob = Action('StartUserImportJob')
StopUserImportJob = Action('StopUserImportJob')
UpdateGroup = Action('UpdateGroup')
UpdateUserPool = Action('UpdateUserPool')
UpdateUserPoolClient = Action('UpdateUserPoolClient')



import unittest

from awacs.helpers.trust import get_default_assumerole_policy


def get_policy_service(policy):
    statement = policy.properties['Statement'][0]
    principal = statement.properties['Principal']
    return principal.data['Service'][0]


class TestTrustHelpers(unittest.TestCase):
    def test_get_default_assumerole_policy(self):
        default_policy = get_default_assumerole_policy('us-east-1')
        cn_policy = get_default_assumerole_policy('cn-north-1')

        self.assertEqual(get_policy_service(default_policy),
                         'ec2.amazonaws.com')
        self.assertEqual(get_policy_service(cn_policy),
                         'ec2.amazonaws.com.cn')


if __name__ == '__main__':
    unittest.main()



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon AppStream 2.0'
prefix = 'appstream'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateFleet = Action('AssociateFleet')
CreateDirectoryConfig = Action('CreateDirectoryConfig')
CreateFleet = Action('CreateFleet')
CreateStack = Action('CreateStack')
CreateStreamingURL = Action('CreateStreamingURL')
DeleteDirectoryConfig = Action('DeleteDirectoryConfig')
DeleteFleet = Action('DeleteFleet')
DeleteStack = Action('DeleteStack')
DescribeDirectoryConfigs = Action('DescribeDirectoryConfigs')
DescribeFleets = Action('DescribeFleets')
DescribeImages = Action('DescribeImages')
DescribeSessions = Action('DescribeSessions')
DescribeStacks = Action('DescribeStacks')
DisassociateFleet = Action('DisassociateFleet')
ExpireSession = Action('ExpireSession')
ListAssociatedFleets = Action('ListAssociatedFleets')
ListAssociatedStacks = Action('ListAssociatedStacks')
StartFleet = Action('StartFleet')
StopFleet = Action('StopFleet')
UpdateDirectoryConfig = Action('UpdateDirectoryConfig')
UpdateFleet = Action('UpdateFleet')
UpdateStack = Action('UpdateStack')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SES'
prefix = 'ses'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CloneReceiptRuleSet = Action('CloneReceiptRuleSet')
CreateReceiptFilter = Action('CreateReceiptFilter')
CreateReceiptRule = Action('CreateReceiptRule')
CreateReceiptRuleSet = Action('CreateReceiptRuleSet')
DeleteIdentity = Action('DeleteIdentity')
DeleteIdentityPolicy = Action('DeleteIdentityPolicy')
DeleteReceiptFilter = Action('DeleteReceiptFilter')
DeleteReceiptRule = Action('DeleteReceiptRule')
DeleteReceiptRuleSet = Action('DeleteReceiptRuleSet')
DeleteVerifiedEmailAddress = Action('DeleteVerifiedEmailAddress')
DescribeActiveReceiptRuleSet = Action('DescribeActiveReceiptRuleSet')
DescribeReceiptRule = Action('DescribeReceiptRule')
DescribeReceiptRuleSet = Action('DescribeReceiptRuleSet')
GetIdentityDkimAttributes = Action('GetIdentityDkimAttributes')
GetIdentityNotificationAttributes = \
    Action('GetIdentityNotificationAttributes')
GetIdentityPolicies = Action('GetIdentityPolicies')
GetIdentityVerificationAttributes = \
    Action('GetIdentityVerificationAttributes')
GetSendQuota = Action('GetSendQuota')
GetSendStatistics = Action('GetSendStatistics')
ListIdentities = Action('ListIdentities')
ListIdentityPolicies = Action('ListIdentityPolicies')
ListReceiptFilters = Action('ListReceiptFilters')
ListReceiptRuleSets = Action('ListReceiptRuleSets')
ListVerifiedEmailAddresses = Action('ListVerifiedEmailAddresses')
PutIdentityPolicy = Action('PutIdentityPolicy')
ReorderReceiptRuleSet = Action('ReorderReceiptRuleSet')
SendBounce = Action('SendBounce')
SendEmail = Action('SendEmail')
SendRawEmail = Action('SendRawEmail')
SetActiveReceiptRuleSet = Action('SetActiveReceiptRuleSet')
SetIdentityDkimEnabled = Action('SetIdentityDkimEnabled')
SetIdentityFeedbackForwardingEnabled = \
    Action('SetIdentityFeedbackForwardingEnabled')
SetIdentityNotificationTopic = Action('SetIdentityNotificationTopic')
SetReceiptRulePosition = Action('SetReceiptRulePosition')
UpdateReceiptRule = Action('UpdateReceiptRule')
VerifyDomainDkim = Action('VerifyDomainDkim')
VerifyDomainIdentity = Action('VerifyDomainIdentity')
VerifyEmailAddress = Action('VerifyEmailAddress')
VerifyEmailIdentity = Action('VerifyEmailIdentity')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Resource Group Tagging API'
prefix = 'tag'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddResourceTags = Action('AddResourceTags')
GetResources = Action('GetResources')
GetTagKeys = Action('GetTagKeys')
GetTagValues = Action('GetTagValues')
RemoveResourceTags = Action('RemoveResourceTags')
TagResources = Action('TagResources')
UntagResources = Action('UntagResources')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS WAF'
prefix = 'waf'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateByteMatchSet = Action('CreateByteMatchSet')
CreateIPSet = Action('CreateIPSet')
CreateRateBasedRule = Action('CreateRateBasedRule')
CreateRule = Action('CreateRule')
CreateSizeConstraintSet = Action('CreateSizeConstraintSet')
CreateSqlInjectionMatchSet = Action('CreateSqlInjectionMatchSet')
CreateWebACL = Action('CreateWebACL')
CreateXssMatchSet = Action('CreateXssMatchSet')
DeleteByteMatchSet = Action('DeleteByteMatchSet')
DeleteIPSet = Action('DeleteIPSet')
DeleteRateBasedRule = Action('DeleteRateBasedRule')
DeleteRule = Action('DeleteRule')
DeleteSizeConstraintSet = Action('DeleteSizeConstraintSet')
DeleteSqlInjectionMatchSet = Action('DeleteSqlInjectionMatchSet')
DeleteWebACL = Action('DeleteWebACL')
DeleteXssMatchSet = Action('DeleteXssMatchSet')
GetByteMatchSet = Action('GetByteMatchSet')
GetChangeToken = Action('GetChangeToken')
GetChangeTokenStatus = Action('GetChangeTokenStatus')
GetIPSet = Action('GetIPSet')
GetRateBasedRule = Action('GetRateBasedRule')
GetRateBasedRuleManagedKeys = Action('GetRateBasedRuleManagedKeys')
GetRule = Action('GetRule')
GetSampledRequests = Action('GetSampledRequests')
GetSizeConstraintSet = Action('GetSizeConstraintSet')
GetSqlInjectionMatchSet = Action('GetSqlInjectionMatchSet')
GetWebACL = Action('GetWebACL')
GetXssMatchSet = Action('GetXssMatchSet')
ListByteMatchSets = Action('ListByteMatchSets')
ListIPSets = Action('ListIPSets')
ListRateBasedules = Action('ListRateBasedules')
ListRules = Action('ListRules')
ListSizeConstraintSets = Action('ListSizeConstraintSets')
ListSqlInjectionMatchSets = Action('ListSqlInjectionMatchSets')
ListWebACLs = Action('ListWebACLs')
ListXssMatchSets = Action('ListXssMatchSets')
UpdateByteMatchSet = Action('UpdateByteMatchSet')
UpdateIPSet = Action('UpdateIPSet')
UpdateRateBasedRule = Action('UpdateRateBasedRule')
UpdateRule = Action('UpdateRule')
UpdateSizeConstraintSet = Action('UpdateSizeConstraintSet')
UpdateSqlInjectionMatchSet = Action('UpdateSqlInjectionMatchSet')
UpdateWebACL = Action('UpdateWebACL')
UpdateXssMatchSet = Action('UpdateXssMatchSet')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT'
prefix = 'iot'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptCertificateTransfer = Action('AcceptCertificateTransfer')
AttachPrincipalPolicy = Action('AttachPrincipalPolicy')
AttachThingPrincipal = Action('AttachThingPrincipal')
CancelCertificateTransfer = Action('CancelCertificateTransfer')
Connect = Action('Connect')
CreateCertificateFromCsr = Action('CreateCertificateFromCsr')
CreateKeysAndCertificate = Action('CreateKeysAndCertificate')
CreatePolicy = Action('CreatePolicy')
CreatePolicyVersion = Action('CreatePolicyVersion')
CreateThing = Action('CreateThing')
CreateThingType = Action('CreateThingType')
CreateTopicRule = Action('CreateTopicRule')
DeleteCACertificate = Action('DeleteCACertificate')
DeleteCertificate = Action('DeleteCertificate')
DeletePolicy = Action('DeletePolicy')
DeletePolicyVersion = Action('DeletePolicyVersion')
DeleteRegistrationCode = Action('DeleteRegistrationCode')
DeleteThing = Action('DeleteThing')
DeleteThingShadow = Action('DeleteThingShadow')
DeleteThingType = Action('DeleteThingType')
DeleteTopicRule = Action('DeleteTopicRule')
DeprecateThingType = Action('DeprecateThingType')
DescribeCaCertificate = Action('DescribeCaCertificate')
DescribeCertificate = Action('DescribeCertificate')
DescribeEndpoint = Action('DescribeEndpoint')
DescribeThing = Action('DescribeThing')
DescribeThingType = Action('DescribeThingType')
DetachPrincipalPolicy = Action('DetachPrincipalPolicy')
DetachThingPrincipal = Action('DetachThingPrincipal')
DisableTopicRule = Action('DisableTopicRule')
EnableTopicRule = Action('EnableTopicRule')
GetLoggingOptions = Action('GetLoggingOptions')
GetPolicy = Action('GetPolicy')
GetPolicyVersion = Action('GetPolicyVersion')
GetRegistrationCode = Action('GetRegistrationCode')
GetThingShadow = Action('GetThingShadow')
GetTopicRule = Action('GetTopicRule')
ListCaCertificates = Action('ListCaCertificates')
ListCertificates = Action('ListCertificates')
ListCertificatesByCa = Action('ListCertificatesByCa')
ListOutgoingCertificates = Action('ListOutgoingCertificates')
ListPolicies = Action('ListPolicies')
ListPolicyPrincipals = Action('ListPolicyPrincipals')
ListPolicyVersions = Action('ListPolicyVersions')
ListPrincipalPolicies = Action('ListPrincipalPolicies')
ListPrincipalThings = Action('ListPrincipalThings')
ListThingPrincipals = Action('ListThingPrincipals')
ListThingTypes = Action('ListThingTypes')
ListThings = Action('ListThings')
ListTopicRules = Action('ListTopicRules')
Publish = Action('Publish')
Receive = Action('Receive')
RegisterCACertificate = Action('RegisterCACertificate')
RegisterCertificate = Action('RegisterCertificate')
RejectCertificateTransfer = Action('RejectCertificateTransfer')
ReplaceTopicRule = Action('ReplaceTopicRule')
SetDefaultPolicyVersion = Action('SetDefaultPolicyVersion')
SetLoggingOptions = Action('SetLoggingOptions')
Subscribe = Action('Subscribe')
TransferCertificate = Action('TransferCertificate')
UpdateCACertificate = Action('UpdateCACertificate')
UpdateCertificate = Action('UpdateCertificate')
UpdateThing = Action('UpdateThing')
UpdateThingShadow = Action('UpdateThingShadow')
